<?php

namespace Drupal\dr8_zth\Entity;

use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\dr8_zth\BlogInterface;
use Drupal\Core\Entity\ContentEntityBase;

/**
 * Class Blog defines the Blog entity class.
 *
 * @ContentEntityType(
 *   id = "blog",
 *   label = @Translation("Blog"),
 *   label_singular = @Translation("blog item"),
 *   label_plural = @Translation("blog items"),
 *   label_count = @PluralTranslation(
 *     singular = "@count blog item",
 *     plural = "@count blog items"
 *   ),
 *   bundle_label = @Translation("Blog type"),
 *   base_table = "blog",
 *   data_table = "blog_field_data",
 *   revision_table = "blog_revision",
 *   revision_data_table = "blog_field_revision",
 *   translatable = TRUE,
 *   list_cache_contexts = {},
 *   entity_keys = {
 *     "id" = "blog_id",
 *     "revision" = "blog_vid",
 *     "bundle" = "type",
 *     "label" = "title",
 *     "langcode" = "langcode",
 *     "uuid" = "uuid",
 *     "status" = "status",
 *     "uid" = "uid",
 *   },
 *   handlers = {
 *     "form" = {
 *       "default" = "Drupal\dr8_zth\Form\BlogForm",
 *       "delete" = "Drupal\dr8_zth\Form\BlogDeleteForm"
 *     },
 *     "list_builder" = "Drupal\dr8_zth\BlogListBuilder",
 *     "route_provider" = {
 *       "html" = "Drupal\Core\Entity\Routing\DefaultHtmlRouteProvider",
 *     }
 *   },
 *   bundle_entity_type = "blog_type",
 *   field_ui_base_route = "entity.blog_type.edit_form",
 *   permission_granularity = "entity_type",
 *   links = {
 *     "add-form" = "/blog/add/{blog_type}",
 *     "add-page" = "/blog/add",
 *     "canonical" = "/blog/{blog}",
 *     "collection" = "/admin/content/blog",
 *     "delete-form" = "/blog/{blog}/delete",
 *     "edit-form" = "/blog/{blog}/edit",
 *     "revision" = "/blog/{blog}/revisions/{blog_revision}/view",
 *     "version-history" = "/blog/{blog}/revisions"
 *   },
 *   admin_permission = "administer blog",
 * )
 */
class Blog extends ContentEntityBase implements BlogInterface {

  /**
   * @var \Drupal\user\Entity\User
   */
  protected $uid;

  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {
    $fields = parent::baseFieldDefinitions($entity_type);
    $fields['title'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Title'))
      ->setRequired(TRUE)
      ->setTranslatable(TRUE)
      ->setRevisionable(TRUE)
      ->setSetting('max_length', 255)
      ->setDisplayOptions('view', array(
        'label' => 'hidden',
        'type' => 'string',
        'weight' => -5,
      ))
      ->setDisplayOptions('form', array(
        'type' => 'string_textfield',
        'weight' => -5,
      ))
      ->setDisplayConfigurable('form', TRUE);

    $fields['uid'] = BaseFieldDefinition::create('entity_reference')
      ->setLabel(t('Authored by'))
      ->setDescription(t('The username of the blog author.'))
      ->setRevisionable(TRUE)
      ->setSetting('target_type', 'user')
      ->setDefaultValueCallback('Drupal\node\Entity\Node::getCurrentUserId')
      ->setTranslatable(TRUE)
      ->setDisplayOptions('view', array(
        'label' => 'hidden',
        'type' => 'author',
        'weight' => 0,
      ))
      ->setDisplayOptions('form', array(
        'type' => 'entity_reference_autocomplete',
        'weight' => 5,
        'settings' => array(
          'match_operator' => 'CONTAINS',
          'size' => '60',
          'placeholder' => '',
        ),
      ))
      ->setDisplayConfigurable('form', TRUE);

    ksm($fields);
    return $fields;
  }

  /**
   * @return \Drupal\user\Entity\User
   */
  public function getAuthor() {
    return $this->get('uid')->entity;
  }

  /**
   * {@inheritdoc}
   */
  public function getAuthorId() {
    return $this->getEntityKey('uid');
  }

}
